All pastes #383361 Raw Edit

Something

public text v1 · immutable
·published 2007-03-06 09:16 UTC
rendered paste body
DU(1)                     BSD General Commands Manual                    DU(1)

NNAAMMEE
     dduu -- display disk usage statistics

SSYYNNOOPPSSIISS
     dduu [--HH | --LL | --PP] [--II _m_a_s_k] [--aa | --ss | --dd _d_e_p_t_h] [--cc] [--hh | --kk] [--xx]
        [_f_i_l_e _._._.]

DDEESSCCRRIIPPTTIIOONN
     The dduu utility displays the file system block usage for each file argu-
     ment and for each directory in the file hierarchy rooted in each direc-
     tory argument.  If no file is specified, the block usage of the hierarchy
     rooted in the current directory is displayed.  If the --kk flag is speci-
     fied, the number of 1024-byte blocks used by the file is displayed, oth-
     erwise getbsize(3) is used to determine the preferred block size.  Par-
     tial numbers of blocks are rounded up.

     The options are as follows:

     --HH      Symbolic links on the command line are followed, symbolic links
             in file hierarchies are not followed.

     --LL      Symbolic links on the command line and in file hierarchies are
             followed.

     --II _m_a_s_k
             Ignore files and directories matching the specified _m_a_s_k.

     --PP      No symbolic links are followed.  This is the default.

     --aa      Display an entry for each file in a file hierarchy.

     --hh      "Human-readable" output.  Use unit suffixes: Byte, Kilobyte,
             Megabyte, Gigabyte, Terabyte and Petabyte

     --rr      Generate messages about directories that cannot be read, files
             that cannot be opened, and so on.  This is the default case.
             This option exists solely for conformance with X/Open Portability
             Guide Issue 4 (``XPG4'').

     --ss      Display an entry for each specified file.  (Equivalent to --dd 0)

     --dd _d_e_p_t_h
             Display an entry for all files and directories _d_e_p_t_h directories
             deep.

     --cc      Display a grand total.

     --kk      Display block counts in 1024-byte (1-Kbyte) blocks.

     --xx      File system mount points are not traversed.

     The dduu utility counts the storage used by symbolic links and not the
     files they reference unless the --HH or --LL option is specified.  If either
     the --HH or --LL options are specified, storage used by any symbolic links
     which are followed is not counted or displayed.

     Files having multiple hard links are counted (and displayed) a single
     time per dduu execution.

EENNVVIIRROONNMMEENNTT
     BLOCKSIZE  If the environment variable BLOCKSIZE is set, and the --kk
                option is not specified, the block counts will be displayed in
                units of that size block.  If BLOCKSIZE is not set, and the --kk
                option is not specified, the block counts will be displayed in
                512-byte blocks.

SSEEEE AALLSSOO
     df(1), fts(3), symlink(7), quot(8)

HHIISSTTOORRYY
     A dduu command appeared in Version 1 AT&T UNIX.

BSD                              April 1, 1994                             BSD